@@ -3,8 +3,8 @@
 base = File.symlink?(__FILE__) ? File.readlink(__FILE__) : __FILE__
 $:.unshift(File.join(File.dirname(base)))
 
-require 'test/unit'
-require 'pcaprub'
+
+require File.expand_path '../test_helper.rb', __FILE__
 
 #
 # Simple unit test, requires r00t.
@@ -56,12 +56,14 @@ class Pcap::UnitTest < Test::Unit::TestCase
     o = Pcap.open_live(d, 65535, true, 1)
     r = o.inject("X" * 512)
 
+    assert_equal(512, r)
+    # UPDATE: TRAVIS CI is now on a new hardware platform.
     # Travis CI's virtual network interface does not support injection
-    if ENV['CI']
-      assert_equal(-1,r)
-    else
-      assert_equal(512, r)
-    end
+    #if ENV['CI']
+    #  assert_equal(-1,r)
+    #else
+    #  assert_equal(512, r)
+    #end
   end
 
   def test_pcap_datalink
@@ -117,10 +119,45 @@ class Pcap::UnitTest < Test::Unit::TestCase
     o.close
   end
 
+  def test_set_datalink
+    d = Pcap.lookupdev
+    o = Pcap.open_live(d, 65535, true, -1)
+    dls = o.listdatalinks
+    begin
+      assert_equal(o,o.setdatalink(dls.values.first))
+    rescue PCAPRUB::LinkTypeError
+      print "#{dls} - Data LinkType Binding issue in the environment (Skipping)"
+      assert_equal(o,o)
+    end
+  end
+
   def test_monitor
     return if RUBY_PLATFORM =~ /mingw|win/
     d = Pcap.lookupdev
     o = Pcap.create(d)
     assert_equal(o, o.setmonitor(true))
   end
+
+  def test_open_dead
+    # No applied filters on OPEN_DEAD just compile checking
+    o = Pcap.open_dead(Pcap::DLT_NULL, 65535)
+    assert_nothing_raised do
+      o.compile("ip host 1.2.3.4")
+    end
+    assert_raise PCAPRUB::BPFError do
+      o.setfilter("ip host 1.2.3.5")
+    end
+  end
+
+  def test_filter
+    d = Pcap.lookupdev
+    o = Pcap.create(d)
+    o.activate
+    assert_nothing_raised do
+      o.compile("ip host 1.2.3.4")
+    end
+    assert_raise PCAPRUB::BPFError do
+      o.compile("A non working filter")
+    end
+  end
 end
